import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../page_wrapper.dart';
import '../panel.dart';

class NotificationSnackbarExample extends StatelessWidget {
  const NotificationSnackbarExample({Key? key}) : super(key: key);

  void showNotificationSnackbarIcon(BuildContext context) {
    showTopSnackBar(
      context: context,
      child: SeniorNotificationSnackbar.icon(
        title: 'Nulla felis velit, consectetur et tincidunt nec, consequat hendrerit ipsum.',
        message:
            'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi at turpis quis dui egestas laoreet. Nam rutrum nibh ac mollis hendrerit. In hac habitasse platea dictumst. Nulla efficitur nec tortor eget volutpat. Nunc rhoncus arcu a gravida aliquet.',
        circleColor: SeniorColors.manchesterColorBlue600,
        iconData: FontAwesomeIcons.info,
      ),
    );
  }

  void showNotificationSnackbarAvatar(BuildContext context) {
    showTopSnackBar(
      context: context,
      child: SeniorNotificationSnackbar.avatar(
        seniorNotificationSnackBarAction: SeniorNotificationSnackBarAction(
          title: 'Ver',
          onPressed: () {
            log('erger');
          },
        ),
        title: 'Nulla felis velit, consectetur et tincidunt',
        message: 'Lorem ipsum dolor sit amet, consectetur',
        employeeName: 'Gustavo Senci',
        imageProvider: NetworkImage(
          'https://tecnoblog.net/wp-content/uploads/2019/12/facebook-mark-zuckerberg-f8-2018-1.jpg',
        ),
      ),
    );
  }

  void showNotificationSnackbar(BuildContext context) {
    showTopSnackBar(
      context: context,
      child: SeniorNotificationSnackbar(
        seniorNotificationSnackBarAction: SeniorNotificationSnackBarAction(
          title: 'Ver',
          onPressed: () {
            print('Ver');
          },
        ),
        title: 'Nulla felis velit, consectetur et tincidunt',
        message: 'Lorem ipsum dolor sit amet, consectetur',
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Snackbar Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Panel(
                title: 'Top Snackbar Icon',
                content: Center(
                  child: SeniorButton(
                    label: 'Mostrar',
                    onPressed: () {
                      showNotificationSnackbarIcon(context);
                    },
                  ),
                ),
              ),
              Panel(
                title: 'Top Snackbar Avatar',
                content: Center(
                  child: SeniorButton(
                    label: 'Mostrar',
                    onPressed: () {
                      showNotificationSnackbarAvatar(context);
                    },
                  ),
                ),
              ),
              Panel(
                title: 'Top Snackbar',
                content: Center(
                  child: SeniorButton(
                    label: 'Mostrar',
                    onPressed: () {
                      showNotificationSnackbar(context);
                    },
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
