import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import '../page_wrapper.dart';
import '../panel.dart';

class TextFieldExample extends StatelessWidget {
  TextFieldExample({Key? key}) : super(key: key);

  bool hidePassword = true;

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Text Field Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(SeniorSpacing.normal),
          child: Column(
            children: [
              Panel(
                title: 'Normal',
                content: SeniorTextField(
                  controller: TextEditingController(),
                  hintText: 'Nome',
                  maxLength: 43,
                  counterCaracterLabel: 'words',
                ),
              ),
              Panel(
                title: 'Text area',
                content: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Descrição',
                  maxLines: 10,
                ),
              ),
              Panel(
                title: 'Limite caracteres',
                content: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Nome',
                  maxLength: 10,
                ),
              ),
              Panel(
                title: 'Com validator',
                content: SeniorTextField(
                  controller: TextEditingController(),
                  maxLength: 30,
                  label: 'Sobrenome',
                  helper: 'Helper do campo',
                  validator: (value) {
                    return value == null || value.isEmpty ? 'Campo obrigatório' : null;
                  },
                ),
              ),
              Panel(
                title: 'Campo de senha',
                content: SeniorTextField.password(
                  controller: TextEditingController(),
                  label: 'Senha',
                  validator: (value) {
                    return value == null || value.isEmpty ? 'Campo obrigatório' : null;
                  },
                  textInputAction: TextInputAction.next,
                ),
              ),
              Panel(
                title: 'Ícone à esquerda',
                content: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Início',
                  leftIcon: FontAwesomeIcons.calendar,
                ),
              ),
              Panel(
                title: 'Ícone à direita',
                content: SeniorTextField(
                  controller: TextEditingController(),
                  label: 'Fim',
                  rightIcon: FontAwesomeIcons.search,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
