import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorAppBarAction {
  final IconData icon;
  final String? tooltip;
  final Function() onPressed;

  const SeniorAppBarAction({
    required this.icon,
    this.tooltip,
    required this.onPressed,
  });
}

abstract class _SeniorAppBar extends StatelessWidget implements PreferredSizeWidget {
  final Widget title;
  final SeniorAppBarAction? leading;
  final List<SeniorAppBarAction>? actions;
  final PreferredSizeWidget? bottom;
  final bool? centerTitle;
  final double? prefSize;

  const _SeniorAppBar({
    Key? key,
    required this.title,
    this.leading,
    this.actions,
    this.bottom,
    this.centerTitle,
    this.prefSize,
  }) : super(key: key);

  @override
  Size get preferredSize => Size.fromHeight(this.prefSize ?? 50.0);

  @override
  Widget build(BuildContext context) {
    return AppBar(
      centerTitle: centerTitle,
      primary: true,
      backgroundColor: Colors.transparent,
      shadowColor: Colors.transparent,
      elevation: 0,
      leading: leading != null
          ? IconButton(
              icon: FaIcon(leading!.icon),
              tooltip: leading!.tooltip,
              onPressed: leading!.onPressed,
              iconSize: SeniorTypographyIconSize.h4,
              color: SeniorColors.neutralColor800,
              splashRadius: 20.0,
            )
          : null,
      title: title,
      actions: actions
          ?.map(
            (action) => IconButton(
              icon: FaIcon(action.icon),
              tooltip: action.tooltip,
              onPressed: action.onPressed,
              iconSize: SeniorTypographyIconSize.h4,
              color: SeniorColors.neutralColor800,
              splashRadius: 20.0,
            ),
          )
          .toList(),
      bottom: bottom,
    );
  }
}

@Deprecated('Use SeniorBackdrop instead')
class SeniorAppBarHome extends _SeniorAppBar {
  SeniorAppBarHome({
    Key? key,
    required String titleImagePath,
    SeniorAppBarAction? leading,
    List<SeniorAppBarAction>? actions,
    PreferredSizeWidget? bottom,
  }) : super(
          key: key,
          title: Image.asset(titleImagePath),
          leading: leading,
          actions: actions,
          bottom: bottom,
          centerTitle: true,
        );
}

@Deprecated('Use SeniorBackdrop instead')
class SeniorAppBarPage extends _SeniorAppBar {
  SeniorAppBarPage({
    Key? key,
    required String title,
    SeniorAppBarAction? leading,
    List<SeniorAppBarAction>? actions,
    PreferredSizeWidget? bottom,
  }) : super(
          key: key,
          title: Text(
            title,
            style: SeniorTypography.h4(
              color: SeniorColors.neutralColor800,
            ),
          ),
          leading: leading,
          actions: actions,
          bottom: bottom,
        );
}

@Deprecated('Use SeniorBackdrop instead')
class SeniorAppBarCustom extends StatelessWidget implements PreferredSizeWidget {
  final Widget? leading;
  final Widget? title;
  final bool? centerTitle;
  final List<Widget>? actions;
  final PreferredSizeWidget? bottom;
  final double? prefSize;

  SeniorAppBarCustom({
    Key? key,
    this.leading,
    this.title,
    this.centerTitle,
    this.actions,
    this.bottom,
    this.prefSize,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AppBar(
      centerTitle: centerTitle,
      primary: true,
      backgroundColor: Colors.transparent,
      shadowColor: Colors.transparent,
      leading: leading,
      title: title,
      actions: actions,
      elevation: 0,
      bottom: bottom,
    );
  }

  @override
  Size get preferredSize => Size.fromHeight(this.prefSize ?? 50.0);
}
