import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_contact_book_item_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorContactBookItem extends StatelessWidget {
  /// Creates the SDS ContactBookItem component.
  const SeniorContactBookItem({
    Key? key,
    this.items,
    this.onTap,
    this.padding = const EdgeInsets.symmetric(
      horizontal: SeniorSpacing.xbig,
      vertical: SeniorSpacing.normal,
    ),
    this.style,
    this.title,
  }) : super(key: key);

  /// The component items.
  /// The information displayed in the component.
  final List<String>? items;

  /// Callback function that is executed when the item is tapped.
  final Function()? onTap;

  /// A padding that will be added to the component.
  ///
  /// The default value is a padding with [SeniorSpacing.xbig] horizontally and [SeniorSpacing.normal] vertically.
  final EdgeInsets padding;

  /// Component style definitions.
  /// Allows you to configure:
  /// [SeniorContactBookItemStyle.titleColor] the color of the item's title.
  /// [SeniorContactBookItemStyle.itemsColor] the color of the item's contents.
  final SeniorContactBookItemStyle? style;

  /// The item's title.
  final String? title;

  Widget _buildItems({
    required SeniorTheme defaultTheme,
    SeniorTheme? theme,
    required List<String>? items,
  }) {
    return items != null
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: items
                .map((item) => Text(
                      item,
                      style: SeniorTypography.small(
                        color: style?.itemsColor ??
                            theme?.contactBookItemTheme?.style?.itemsColor ??
                            defaultTheme.contactBookItemTheme?.style?.itemsColor ??
                            SeniorColors.neutralColor500,
                      ),
                    ))
                .toList(),
          )
        : SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    return InkWell(
      onTap: onTap,
      child: Container(
        padding: padding,
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            title == null
                ? SizedBox.shrink()
                : Container(
                    padding: items != null ? const EdgeInsets.only(bottom: SeniorSpacing.xxsmall) : null,
                    child: Text(
                      title!,
                      style: SeniorTypography.body(
                        color: style?.titleColor ??
                            theme?.contactBookItemTheme?.style?.titleColor ??
                            defaultTheme.contactBookItemTheme?.style?.titleColor ??
                            SeniorColors.neutralColor800,
                      ),
                    ),
                  ),
            _buildItems(items: items, defaultTheme: defaultTheme, theme: theme),
          ],
        ),
      ),
    );
  }
}
