import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import './senior_theme.dart';
import './senior_themes/senior_themes.dart';

class SeniorThemeProvider {
  /// Obtém o tema aplicado ao app pelo Provider.
  /// O parâmetro [context] equivale ao contexto atual do app.
  /// O parâmetro [listen] será repassado para o [Provider.of].
  static SeniorTheme? getTheme(BuildContext context, {bool listen = true}) {
    SeniorTheme? theme = Provider.of<SeniorTheme?>(context, listen: listen);
    return theme;
  }

  /// Obtem o tema padrão de acordo com o brightness configurado no app.
  /// Por padrão retorna o [seniorLightTheme].
  static SeniorTheme getDefaultTheme(BuildContext context) {
    final Brightness brightness = MediaQuery.of(context).platformBrightness;
    return brightness == Brightness.dark ? seniorDarkTheme : seniorLightTheme;
  }
}
